import React from "react";
import withStage from "./withStage";
import SceneTransition from "./SceneTransition";
class SceneTransitioner extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {};
        this.handleAddScene = (sceneId, scene) => {
            const { from, to } = this.state;
            if (from === sceneId) {
                this.setState({
                    fromScene: scene
                });
            }
            else if (to === sceneId) {
                this.setState({
                    toScene: scene
                });
            }
            this.props.stage.removeAddSceneListener(sceneId, this.handleAddScene);
        };
        this.onFinish = () => {
            const { onFinish } = this.state;
            this.setState({
                from: undefined,
                fromScene: undefined,
                to: undefined,
                toScene: undefined,
                springConfig: undefined,
                onFinish: undefined
            });
            if (onFinish) {
                onFinish();
            }
        };
    }
    transition({ from, to, springConfig, onFinish }) {
        const { stage } = this.props;
        const fromScene = stage.getScene(from);
        const toScene = stage.getScene(to);
        if (!fromScene) {
            stage.onAddScene(from, this.handleAddScene);
        }
        if (!toScene) {
            stage.onAddScene(to, this.handleAddScene);
        }
        this.setState({
            from,
            fromScene,
            to,
            toScene,
            springConfig,
            onFinish
        });
    }
    render() {
        const { fromScene, toScene, springConfig } = this.state;
        if (!fromScene || !toScene) {
            return null;
        }
        return (<SceneTransition from={fromScene} to={toScene} springConfig={springConfig} onFinish={this.onFinish}/>);
    }
}
export default withStage(SceneTransitioner);
//# sourceMappingURL=SceneTransitioner.js.map